@@ -130,11 +130,8 @@ namespace Banter
 			// Initialize the Theme Manager
 			// ThemeManager.Init ();
 
-			//tray = new NotificationArea("RtcApplication");
-			SetupTrayIcon();
-
 			application = this;
-			
+
 			groupWindows = new Dictionary<GroupWindow, GroupWindow> ();
 
 			GLib.Idle.Add(InitializeIdle);
@@ -161,6 +158,9 @@ namespace Banter
 		{
 			Logger.Debug ("Initialize_Idle - called");
 
+			SetupTrayIcon();
+			OpenSavedGroupWindows();
+
 			//GConfPreferencesProvider prefs = new GConfPreferencesProvider ();
 			//Preferences.Init (prefs);
 			//Preferences.SettingChanged += CompDirApplication.SettingChanged;
@@ -201,8 +201,6 @@ namespace Banter
 		{
 			Logger.Debug ("OnAccountManagementReady() called");
 			initialized = true;
-			
-			GLib.Idle.Add (OpenSavedGroupWindows);
 		}
 		
 		private bool OpenSavedGroupWindows ()
@@ -244,7 +242,17 @@ namespace Banter
 				return;
 				
 			if (args.Event.Button == 1) {
-				Logger.Debug ("left button clicked");
+				if (groupWindows.Count <= 0) {
+					GroupWindow gw = new GroupWindow();
+					groupWindows [gw] = gw;
+					gw.DeleteEvent += OnGroupWindowDeleted;
+					gw.ShowAll ();
+				} else {
+					foreach(GroupWindow gw in groupWindows.Values) {
+						gw.Present();
+					}
+				}
+				    
 			} else if (args.Event.Button == 3) //right click
    			{
    				// FIXME: Eventually get all these into UIManagerLayout.xml file
@@ -326,14 +334,26 @@ namespace Banter
 		{
 			Logger.Info ("OnQuitAction called - terminating application");
 
+			trayIcon.Hide();
+
 			// Save off the GroupWindow states
 			if (groupWindows.Count > 0) {
 				Logger.Info ("Saving the state of all group windows...");
 				foreach (GroupWindow gw in groupWindows.Values) {
 					gw.SaveState ();
+					gw.Hide();
 				}
 			}
-			
+
+			// close all chat windows
+			ChatWindowManager.CloseAllChatWindows();
+
+			// Give the appearance of quitting quickly even though we don't
+			GLib.Idle.Add(ShutdownIdle);
+		}
+
+		private bool ShutdownIdle()
+		{
 			AccountManagement.Shutdown();
 			Logger.Debug ("Finished Disconnecting accounts");
 
@@ -342,9 +362,10 @@ namespace Banter
 			
 			// Shutdown the message log store
 			//MessageStore.Stop ();
-			
+
 			Gtk.Main.Quit ();
 			//program.Quit (); // Should this be called instead?
+			return false;
 		}
 		
 		private void OnShowPreferencesAction (object sender, EventArgs args)
