@@ -45,6 +45,18 @@ namespace Banter
 	public delegate void ProviderUserAvatarUpdatedHandler (ProviderUser user, string newToken);
 	public delegate void ProviderUserAvatarReceivedHandler (ProviderUser user, string token, string mimeType, byte[] avatarData);
 
+	///<summary>
+	///	ProviderUserRelationship Enum
+	/// represents the relationship of the provider user
+	///</summary>
+	public enum ProviderUserRelationship
+	{
+		Unknown,
+		Linked,
+		SentInvitation,
+		ReceivedInvitation
+	}
+	
 	///<summary>
 	///	ProviderUser Class
 	/// ProviderUser represents buddies from providers in telepathy.
@@ -61,6 +73,7 @@ namespace Banter
 		private string accountName;
 		private bool isMe;
 		private IConnection tlpConnection;
+		private ProviderUserRelationship relationship;
 		#endregion		
 		
 		#region Public Events
@@ -188,6 +201,16 @@ namespace Banter
 			get { return accountName; }
 			set { this.accountName = value; }
 		}		
+
+		/// <summary>
+		/// Current user's relationship to the provider user
+		/// Linked, SentInvitation, ReceivedInvitation
+		/// </summary>		
+		public ProviderUserRelationship Relationship
+		{
+			get { return relationship; }
+			set { this.relationship = value; }
+		}	
 		
 
 		/// <summary>
@@ -218,6 +241,7 @@ namespace Banter
 		public ProviderUser()
 		{
 			this.presence = new Presence(PresenceType.Offline);
+			this.relationship = ProviderUserRelationship.Unknown;
 			this.uri = String.Empty;
 			this.accountName = String.Empty;
 			this.alias = String.Empty;
@@ -240,6 +264,70 @@ namespace Banter
 		#endregion		
 		
 		#region Public Methods
+		/// <summary>
+		/// Authorize a user to enable chatting
+		/// the user must be in the correct relationship state to authorize
+		/// </summary>
+        public void Authorize (string message)
+        {
+        	if (this.relationship != ProviderUserRelationship.ReceivedInvitation)
+        		throw new ApplicationException ("User is not in a the correct authorization state");
+        		
+			// Need to get the account information so we can AddMember
+			// to the correct group
+			Account account = AccountManagement.GetAccountByName (this.accountName);
+			account.AuthorizeUser (true, this.id, message);
+			this.relationship = ProviderUserRelationship.Linked;			
+        }
+
+		/// <summary>
+		/// Deny a user who is requesting authorization to chat
+		/// </summary>
+        public void DenyAuthorization (string message)
+        {
+        	if (this.relationship != ProviderUserRelationship.ReceivedInvitation)
+        		throw new ApplicationException ("User is not in the ReceivedInvitation state");
+        		
+			// Need to get the account information so we can AddMember
+			// to the correct group
+			Account account = AccountManagement.GetAccountByName (this.accountName);
+			account.AuthorizeUser (false, this.id, message);
+			this.relationship = ProviderUserRelationship.Unknown;	
+			
+			ProviderUserManager.RemoveProviderUser (this.uri, this.protocol);
+        }
+
+		/// <summary>
+		/// Method to revoke an outstanding invitation
+		/// </summary>
+        public void RevokeInvitation ()
+        {
+        	if (this.relationship != ProviderUserRelationship.SentInvitation)
+        		throw new ApplicationException ("User is not in the SentInvitation relationship state");
+        		
+			// Need to get the account information so we can AddMember
+			// to the correct group
+			Account account = AccountManagement.GetAccountByName (this.accountName);
+			
+			account.RemoveUser (this.id, String.Empty);
+			this.relationship = ProviderUserRelationship.Unknown;
+			ProviderUserManager.RemoveProviderUser (this.uri, this.protocol);
+        }
+
+		/// <summary>
+		/// Method to remove a user's membership with the current user
+		/// </summary>
+        public void RemoveUser ()
+        {
+        	if (this.relationship != ProviderUserRelationship.Linked)
+        		throw new ApplicationException ("User is not in the Linked relationship state");
+        		
+			// Need to get the account information so we can Remove the member
+			Account account = AccountManagement.GetAccountByName (this.accountName);
+			account.RemoveUser (this.id, String.Empty);
+			ProviderUserManager.RemoveProviderUser (this.uri, this.protocol);
+        }
+
 		public void RequestAvatarData ()
 		{
 			if (tlpConnection == null) return;
@@ -261,7 +349,7 @@ namespace Banter
 				AvatarReceived (this, tokens[0], avatarData.MimeType, avatarData.Data);
 		}
 
-		public void SetStatus(Presence myPresence)
+		public void SetStatus (Presence myPresence)
         {
         	if(tlpConnection.Status == org.freedesktop.Telepathy.ConnectionStatus.Connected) {
 				Dictionary<string, IDictionary<string, object>> presence = new Dictionary<string, IDictionary<string, object>>();
@@ -273,7 +361,7 @@ namespace Banter
         	}
         }
 
-		public void SetAvatar(string mimeType, byte[] data)
+		public void SetAvatar (string mimeType, byte[] data)
         {
         	if(tlpConnection.Status == org.freedesktop.Telepathy.ConnectionStatus.Connected) {
         		org.freedesktop.Telepathy.Avatar aphoto = new org.freedesktop.Telepathy.Avatar();
@@ -282,7 +370,7 @@ namespace Banter
 				tlpConnection.SetAvatar(aphoto);
         	}
         }
-
+        
 
 		#endregion
 	}
